class Fraction:
#The Fraction class implements non-negative fractions, i.e., rational numbers.

	def __init__(self, top, bottom):
	#Constructs a Fraction num/den
		common = Fraction.gcd(top, bottom) #get largest common term
		self.num = top			 #numerator
		self.den = bottom	   #denominator

	def __repr__(self):
	#Computes the "official" string reputation of a Fraction
		return 'Fraction({0}, {1})'.format(self.num, self.den)

	def __str__(self):
	#Computes the "informal" string representations of a Fraction.
		return str(self.num) + '/' + str(self.den)

	def __add__(self, other):
	#Adds two fractions and return the result. 
		new_num = self.num * other.den + self.den * other.num
		new_den = self.den * other.den
		return Fraction(new_num, new_den)

	def __sub__(self, other):
	#subtracts two fractions and return the result. 
		new_num = self.num * other.den - self.den * other.num
		new_den = self.den * other.den
		return Fraction(new_num, new_den)

	def __mul__(self, other):
	#multiply two fractions and return the result. 
		new_num = self.num * other.num
		new_den = self.den * other.den
		return Fraction(new_num, new_den)

	def __truediv__(self, other):
	#divide two fractions and return the result. 
		new_num = self.num * other.den
		new_den = self.den * other.num
		return Fraction(new_num, new_den)

	def __eq__(self, other):
	#Determines whether or not two points are equal.
		if not isinstance(other, Fraction):
			return False
		return self.num * other.den == other.num * self.den

	def __lt__(self, other):
	#Determines if itself is less than other
		num1 = self.num * other.den
		num2 = self.den * other.num
		return num1 < num2

	def gcd(m, n):
	#Computes the greatest common divisor (gcd) of the two numbers.
		while m % n != 0:
			old_m = m
			old_n = n
			m = old_n
			n = old_m % old_n
		return n

